@@ -15,6 +15,7 @@
 
 #include <chrono>
 
+#include <knotification.h>
 #include <wayland-client.h>
 
 K_PLUGIN_CLASS_WITH_JSON(KdedDeviceNotifications, "devicenotifications.json")
@@ -322,6 +323,14 @@ void KdedDeviceNotifications::setupWaylandOutputListener()
     wl_callback_add_listener(syncCallback, &syncCallbackListener, this);
 }
 
+void KdedDeviceNotifications::dismissUsbDeviceAdded()
+{
+    if (m_usbDeviceAddedNotification) {
+        m_usbDeviceAddedNotification->close();
+        m_usbDeviceAddedNotification = nullptr;
+    }
+}
+
 void KdedDeviceNotifications::notifyOutputAdded()
 {
     if (m_deviceAddedTimer.isActive()) {
@@ -330,7 +339,7 @@ void KdedDeviceNotifications::notifyOutputAdded()
 
     KNotification::event(QStringLiteral("deviceAdded"),
                          i18nc("@title:notifications", "Display Detected"),
-                         i18n("A display has been plugged in."),
+                         i18n("A display has been connected."),
                          QStringLiteral("video-display-add"),
                          KNotification::DefaultEvent);
     m_deviceAddedTimer.start();
@@ -344,7 +353,7 @@ void KdedDeviceNotifications::notifyOutputRemoved()
 
     KNotification::event(QStringLiteral("deviceRemoved"),
                          i18nc("@title:notifications", "Display Removed"),
-                         i18n("A display has been unplugged."),
+                         i18n("A display has been disconnected."),
                          QStringLiteral("video-display-remove"),
                          KNotification::DefaultEvent);
     m_deviceRemovedTimer.start();
@@ -375,13 +384,30 @@ void KdedDeviceNotifications::onDeviceAdded(const UdevDevice &device)
         return;
     }
 
-    const QString text = !displayName.isEmpty() ? i18n("%1 has been plugged in.", displayName.toHtmlEscaped()) : i18n("A USB device has been plugged in.");
+    // If the user unplugged something and then immediately plugged it in again,
+    // there's no need to keep the unplug notification around.
+    if (m_usbDeviceRemovedNotification) {
+        m_usbDeviceRemovedNotification->close();
+        m_usbDeviceRemovedNotification = nullptr;
+    }
+
+    // Only show one of these at a time. We already suppressed creating a bunch
+    // in quick succession for the dock/hub use case, so any that are created
+    // over that time limit anyway are not necessary to stack up.
+    if (m_usbDeviceAddedNotification) {
+        m_usbDeviceAddedNotification->close();
+        m_usbDeviceAddedNotification = nullptr;
+    }
+
+    const QString text = !displayName.isEmpty() ? i18n("%1 has been connected.", displayName.toHtmlEscaped()) : i18n("A USB device has been connected.");
+
+    m_usbDeviceAddedNotification = new KNotification(QStringLiteral("deviceAdded"));
+    m_usbDeviceAddedNotification->setFlags(KNotification::DefaultEvent);
+    m_usbDeviceAddedNotification->setIconName(QStringLiteral("drive-removable-media-usb"));
+    m_usbDeviceAddedNotification->setTitle(i18nc("@title:notifications", "USB Device Detected"));
+    m_usbDeviceAddedNotification->setText(text);
+    m_usbDeviceAddedNotification->sendEvent();
 
-    KNotification::event(QStringLiteral("deviceAdded"),
-                         i18nc("@title:notifications", "USB Device Detected"),
-                         text,
-                         QStringLiteral("drive-removable-media-usb"),
-                         KNotification::DefaultEvent);
     m_deviceAddedTimer.start();
 }
 
@@ -401,13 +427,30 @@ void KdedDeviceNotifications::onDeviceRemoved(const UdevDevice &device)
         return;
     }
 
-    const QString text = !displayName.isEmpty() ? i18n("%1 has been unplugged.", displayName.toHtmlEscaped()) : i18n("A USB device has been unplugged.");
+    // If the user plugged something in and then immediately unplugged it again,
+    // there's no need to keep the plug notification around.
+    if (m_usbDeviceAddedNotification) {
+        m_usbDeviceAddedNotification->close();
+        m_usbDeviceAddedNotification = nullptr;
+    }
+
+    // Only show one of these at a time. We already suppressed removing a bunch
+    // in quick succession for the dock/hub use case, so any that are removed
+    // over that time limit anyway are not necessary to stack up.
+    if (m_usbDeviceRemovedNotification) {
+        m_usbDeviceRemovedNotification->close();
+        m_usbDeviceRemovedNotification = nullptr;
+    }
+
+    const QString text = !displayName.isEmpty() ? i18n("%1 has been disconnected.", displayName.toHtmlEscaped()) : i18n("A USB device has been disconnected.");
+
+    m_usbDeviceRemovedNotification = new KNotification(QStringLiteral("deviceRemoved"));
+    m_usbDeviceRemovedNotification->setFlags(KNotification::DefaultEvent);
+    m_usbDeviceRemovedNotification->setIconName(QStringLiteral("drive-removable-media-usb"));
+    m_usbDeviceRemovedNotification->setTitle(i18nc("@title:notifications", "USB Device Went Away"));
+    m_usbDeviceRemovedNotification->setText(text);
+    m_usbDeviceRemovedNotification->sendEvent();
 
-    KNotification::event(QStringLiteral("deviceRemoved"),
-                         i18nc("@title:notifications", "USB Device Removed"),
-                         text,
-                         QStringLiteral("drive-removable-media-usb"),
-                         KNotification::DefaultEvent);
     m_deviceRemovedTimer.start();
 }
 
