@@ -8,11 +8,13 @@
 
 #include <QHash>
 #include <QList>
+#include <QPointer>
 #include <QSocketNotifier>
 #include <QString>
 #include <QTimer>
 
 #include <KDEDModule>
+#include <KNotification>
 
 #include <libudev.h>
 
@@ -75,6 +77,7 @@ private:
 class KdedDeviceNotifications : public KDEDModule
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.kde.plasma.devicenotifications")
 
 public:
     KdedDeviceNotifications(QObject *parent, const QVariantList &args);
@@ -82,6 +85,8 @@ public:
 
     void setupWaylandOutputListener();
 
+    Q_SCRIPTABLE void dismissUsbDeviceAdded();
+
 private:
     void notifyOutputAdded();
     void notifyOutputRemoved();
@@ -98,4 +103,7 @@ private:
 
     QTimer m_deviceAddedTimer;
     QTimer m_deviceRemovedTimer;
+
+    QPointer<KNotification> m_usbDeviceAddedNotification;
+    QPointer<KNotification> m_usbDeviceRemovedNotification;
 };
