@@ -77,10 +77,14 @@ class User : public QObject
 
     Q_PROPERTY(bool faceValid READ faceValid NOTIFY faceValidChanged)
 
-    Q_PROPERTY(bool loggedIn READ loggedIn CONSTANT)
+    Q_PROPERTY(bool isCurrentUser READ isCurrentUser CONSTANT)
+
+    Q_PROPERTY(bool loggedIn READ loggedIn NOTIFY loggedInChanged)
 
     Q_PROPERTY(bool administrator READ administrator WRITE setAdministrator NOTIFY administratorChanged)
 
+    Q_PROPERTY(QUrl lastFileDialogLocation READ lastFileDialogLocation WRITE setLastFileDialogLocation NOTIFY lastFileDialogLocationChanged)
+
 public:
     explicit User(QObject *parent = nullptr);
 
@@ -94,10 +98,12 @@ public:
     QString email() const;
     QUrl face() const;
     bool faceValid() const;
+    bool isCurrentUser() const;
     bool loggedIn() const;
     bool administrator() const;
     QDBusObjectPath path() const;
     QRect faceCrop() const;
+    QUrl lastFileDialogLocation() const;
 
     void setName(const QString &value);
     void setRealName(const QString &value);
@@ -106,6 +112,7 @@ public:
     void setAdministrator(bool value);
     void setPath(const QDBusObjectPath &path);
     void setFaceCrop(const QRect &rect);
+    void setLastFileDialogLocation(QUrl &url);
 
     void loadData();
 
@@ -122,11 +129,13 @@ Q_SIGNALS:
     void realNameChanged();
     void displayNamesChanged();
     void emailChanged();
+    void loggedInChanged();
     void faceChanged();
     void faceValidChanged();
     void administratorChanged();
     void applyError(const QString &errorMessage);
     void passwordSuccessfullyChanged();
+    void lastFileDialogLocationChanged();
 
 private:
     qulonglong mUid = 0;
@@ -145,9 +154,11 @@ private:
     bool mOriginalAdministrator = false;
     bool mFaceValid = false;
     bool mOriginalFaceValid = false;
+    bool mIsCurrentUser = false;
     bool mLoggedIn = false;
     bool mOriginalLoggedIn = false;
     QDBusObjectPath mPath;
     QPointer<OrgFreedesktopAccountsUserInterface> m_dbusIface;
     std::optional<QString> mError;
+    QUrl m_lastFileDialogLocation;
 };
