@@ -68,7 +68,7 @@ public:
     bool requestRemoveLauncherFromActivities(const QUrl &_url, const QStringList &activities);
 
 private:
-    LauncherTasksModel *q;
+    LauncherTasksModel *const q;
 };
 
 LauncherTasksModel::Private::Private(LauncherTasksModel *q)
@@ -592,3 +592,5 @@ void LauncherTasksModel::requestOpenUrls(const QModelIndex &index, const QList<Q
 }
 
 }
+
+#include "moc_launchertasksmodel.cpp"
