@@ -97,8 +97,8 @@ QList<BookmarkMatch> Chrome::match(const QString &term, bool addEveryThing, Prof
     Favicon *favicon = profileBookmarks->profile().favicon();
     for (const QJsonValue &bookmarkValue : bookmarks) {
         const QJsonObject bookmark = bookmarkValue.toObject();
-        const QString url = bookmark.value(QStringLiteral("url")).toString();
-        BookmarkMatch bookmarkMatch(favicon->iconFor(url), term, bookmark.value(QStringLiteral("name")).toString(), url);
+        const QString url = bookmark.value(u"url").toString();
+        BookmarkMatch bookmarkMatch(favicon->iconFor(url), term, bookmark.value(u"name").toString(), url);
         bookmarkMatch.addTo(results, addEveryThing);
     }
     return results;
@@ -126,3 +126,5 @@ void Chrome::teardown()
         profileBookmarks->tearDown();
     }
 }
+
+#include "moc_chrome.cpp"
