@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2016-2021 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2016-2025 Harald Sitter <sitter@kde.org>
     SPDX-FileCopyrightText: 2022 Alexander Lohnau <alexander.lohnau@gmx.de>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
@@ -20,14 +20,31 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+using namespace Qt::StringLiterals;
+
 class ServiceRunnerTest : public KRunner::AbstractRunnerTest
 {
     Q_OBJECT
+
+    template<typename... Args>
+    auto launchQueryAndSort(Args &&...args)
+    {
+        auto matches = launchQuery(std::forward<Args>(args)...);
+        // Make sure overlapping scores still result in a stable sorting order. Avoids flakes
+        std::ranges::sort(matches, [](const KRunner::QueryMatch &a, const KRunner::QueryMatch &b) {
+            return a.text() > b.text();
+        });
+        std::ranges::stable_sort(matches, [](const KRunner::QueryMatch &a, const KRunner::QueryMatch &b) {
+            return a.relevance() > b.relevance();
+        });
+        return matches;
+    }
+
 private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
 
-    void testExcutableExactMatch();
+    void testExecutableExactMatch();
     void testKonsoleVsYakuakeComment();
     void testSystemSettings();
     void testSystemSettings2();
@@ -36,6 +53,11 @@ private Q_SLOTS:
     void testINotifyUsage();
     void testSpecialArgs();
     void testEnv();
+    void testCodeVsKateVsEmojier();
+    void testDisassociation();
+    void testMultipleKeywords();
+    void testMultipleNameWords();
+    void testDiscover();
 };
 
 void ServiceRunnerTest::initTestCase()
@@ -76,38 +98,31 @@ void ServiceRunnerTest::cleanupTestCase()
 {
 }
 
-void ServiceRunnerTest::testExcutableExactMatch()
+void ServiceRunnerTest::testExecutableExactMatch()
 {
     const auto matches = launchQuery(QStringLiteral("Virtual Machine Manager ServiceRunnerTest")); // virt-manager.desktop
     QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const KRunner::QueryMatch &match) {
-        return match.text() == QLatin1String("Virtual Machine Manager ServiceRunnerTest") && match.relevance() == 1;
+        return match.text() == QLatin1String("Virtual Machine Manager ServiceRunnerTest") && match.relevance() >= 1;
     }));
 }
 
 void ServiceRunnerTest::testKonsoleVsYakuakeComment()
 {
-    // Yakuake has konsole mentioned in comment, should be rated lower.
-    const auto matches = launchQuery(QStringLiteral("kons"));
+    // Yakuake has konsole mentioned in comment, should not be listed (if it was it should be lower)
+    auto matches = launchQueryAndSort(QStringLiteral("kons"));
 
-    bool konsoleFound = false;
-    bool yakuakeFound = false;
+    QStringList texts;
     for (const auto &match : matches) {
-        qDebug() << "matched" << match.text();
-        if (!match.text().contains(QLatin1String("ServiceRunnerTest"))) {
+        if (!match.text().contains("ServiceRunnerTest"_L1)) {
             continue;
         }
-
-        if (match.text() == QLatin1String("Konsole ServiceRunnerTest")) {
-            QCOMPARE(match.relevance(), 0.99);
-            konsoleFound = true;
-        } else if (match.text() == QLatin1String("Yakuake ServiceRunnerTest")) {
-            // Rates lower because it doesn't have it in the name.
-            QCOMPARE(match.relevance(), 0.59);
-            yakuakeFound = true;
-        }
+        texts.push_back(match.text());
     }
-    QVERIFY(konsoleFound);
-    QVERIFY(yakuakeFound);
+
+    QCOMPARE(texts,
+             QStringList({
+                 u"Konsole ServiceRunnerTest"_s,
+             }));
 }
 
 void ServiceRunnerTest::testSystemSettings()
@@ -118,40 +133,37 @@ void ServiceRunnerTest::testSystemSettings()
     // may then also disqualify the KDE version of system settings on account of having already
     // seen it. This test makes sure we find the right version.
     manager->matchSessionComplete();
-    const auto matches = launchQuery(QStringLiteral("settings"));
+    auto matches = launchQueryAndSort(QStringLiteral("settings"));
 
-    bool systemSettingsFound = false;
-    bool foreignSystemSettingsFound = false;
+    QStringList texts;
     for (const auto &match : matches) {
-        qDebug() << "matched" << match;
-        if (match.text() == QLatin1String("System Settings ServiceRunnerTest")) {
-            systemSettingsFound = true;
-        }
-        if (match.text() == QLatin1String("KDE System Settings ServiceRunnerTest")) {
-            foreignSystemSettingsFound = true;
+        if (!match.text().contains("ServiceRunnerTest"_L1)) {
+            continue;
         }
+        texts.push_back(match.text());
     }
-    QVERIFY(systemSettingsFound);
-    QVERIFY(!foreignSystemSettingsFound);
+
+    QCOMPARE(texts,
+             QStringList({
+                 u"System Settings ServiceRunnerTest"_s,
+                 u"VirtThings ServiceRunnerTest"_s, // is in settings category
+             }));
 }
 
 void ServiceRunnerTest::testSystemSettings2()
 {
-    const auto matches = launchQuery(QStringLiteral("sy"));
+    auto matches = launchQueryAndSort(QStringLiteral("sy"));
 
-    bool systemSettingsFound = false;
-    bool foreignSystemSettingsFound = false;
+    QStringList texts;
     for (const auto &match : matches) {
-        qDebug() << "matched" << match.text();
-        if (match.text() == QLatin1String("System Settings ServiceRunnerTest")) {
-            systemSettingsFound = true;
-        }
-        if (match.text() == QLatin1String("KDE System Settings ServiceRunnerTest")) {
-            foreignSystemSettingsFound = true;
+        if (!match.text().contains("ServiceRunnerTest"_L1)) {
+            continue;
         }
+        texts.push_back(match.text());
     }
-    QVERIFY(systemSettingsFound);
-    QVERIFY(!foreignSystemSettingsFound);
+
+    // The matched texts will contain much more because of the generic search term. Make sure our settings win.
+    QCOMPARE(texts.at(0), u"System Settings ServiceRunnerTest"_s);
 }
 
 void ServiceRunnerTest::testCategories()
@@ -172,10 +184,6 @@ void ServiceRunnerTest::testCategories()
     QVERIFY(std::none_of(matches.cbegin(), matches.cend(), [](const KRunner::QueryMatch &match) {
         return match.text() == QLatin1String("Konsole ServiceRunnerTest");
     }));
-
-    // Query too short to match any category
-    matches = launchQuery(QStringLiteral("Dumm"));
-    QVERIFY(matches.isEmpty());
 }
 
 void ServiceRunnerTest::testJumpListActions()
@@ -234,6 +242,91 @@ void ServiceRunnerTest::testEnv()
     }));
 }
 
+void ServiceRunnerTest::testCodeVsKateVsEmojier()
+{
+    // Kate has code mentioned in comment, should be rated lower.
+    auto matches = launchQueryAndSort(u"code"_s);
+
+    QStringList texts;
+    for (const auto &match : matches) {
+        if (!match.text().contains("ServiceRunnerTest"_L1)) {
+            continue;
+        }
+        texts.push_back(match.text());
+    }
+
+    QCOMPARE(texts,
+             QStringList({
+                 u"Code - OSS ServiceRunnerTest"_s,
+                 u"Visual Studio Code ServiceRunnerTest"_s,
+                 u"Discover ServiceRunnerTest"_s, // fuzzy match... disCO*Er
+                 // keyword match
+                 u"Kate ServiceRunnerTest"_s,
+             }));
+}
+
+void ServiceRunnerTest::testDisassociation()
+{
+    // This test makes sure that we do not associate a service with a query that is not relevant.
+    auto matches = launchQueryAndSort(u"new laptop com"_s); // particularly notorious because it has two three letter words; 'com' is an incomplete word
+
+    QStringList texts;
+    for (const auto &match : matches) {
+        texts.push_back(match.text());
+    }
+
+    QCOMPARE(texts, QStringList());
+}
+
+void ServiceRunnerTest::testMultipleKeywords()
+{
+    auto matches = launchQueryAndSort(u"text editor programming"_s);
+
+    QStringList texts;
+    for (const auto &match : matches) {
+        texts.push_back(match.text());
+    }
+
+    QCOMPARE(texts,
+             QStringList({
+                 u"Kate ServiceRunnerTest"_s,
+             }));
+}
+
+void ServiceRunnerTest::testMultipleNameWords()
+{
+    auto matches = launchQueryAndSort(u"system settings"_s);
+
+    QStringList texts;
+    for (const auto &match : matches) {
+        if (!match.text().contains("ServiceRunnerTest"_L1)) {
+            continue;
+        }
+        texts.push_back(match.text());
+    }
+
+    QCOMPARE(texts,
+             QStringList({
+                 u"System Settings ServiceRunnerTest"_s,
+             }));
+}
+
+void ServiceRunnerTest::testDiscover()
+{
+    auto matches = launchQueryAndSort(u"disco"_s);
+
+    QStringList texts;
+    for (const auto &match : matches) {
+        texts.push_back(match.text());
+    }
+
+    qDebug() << texts;
+    QCOMPARE(texts,
+             QStringList({
+                 u"Discover ServiceRunnerTest"_s,
+             }));
+}
+
 QTEST_MAIN(ServiceRunnerTest)
 
 #include "servicerunnertest.moc"
