@@ -964,7 +964,7 @@ void PanelView::showConfigurationInterface(Plasma::Applet *applet)
             configView->setAnimated(true);
             m_panelConfigView = configView;
 
-            connect(this, &PanelView::formFactorChanged, m_panelConfigView, [&]() {
+            connect(this, &PanelView::formFactorChanged, this, [&]() {
                 // The panel window will resize first, and the content
                 // will follow. We first unset the visual parent so that
                 // the config view does not reposition in the incorrect
@@ -1699,6 +1699,9 @@ void PanelView::refreshContainment()
             cont->setStatus(Plasma::Types::ActiveStatus);
         }
     });
+    if (m_screenToFollow) {
+        setVisible(true);
+    }
 }
 
 void PanelView::handleQmlStatusChange(QQmlComponent::Status status)
