@@ -38,69 +38,58 @@ QVariant PackageListModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    const KPackage::Package &b = m_packages.at(index.row());
+    const WallpaperPackage &b = m_packages.at(index.row());
 
-    if (!b.isValid()) {
+    if (!b.package().isValid()) {
         Q_UNREACHABLE(); // Should be already filtered out by the finder
     }
 
     switch (role) {
     case Qt::DisplayRole:
-        return PackageFinder::packageDisplayName(b);
+        return b.displayName();
 
     case PreviewRole: {
         QUrl previewUrl(QStringLiteral("image://wallpaper-preview"));
         previewUrl.setQuery({
-            std::make_pair(QStringLiteral("package"), b.path()),
+            std::make_pair(QStringLiteral("package"), b.package().path()),
         });
         return previewUrl;
     }
 
     case AuthorRole: {
-        if (!b.metadata().authors().empty()) {
-            return b.metadata().authors().at(0).name();
+        if (!b.package().metadata().authors().empty()) {
+            return b.package().metadata().authors().at(0).name();
         }
 
         return QString();
     }
 
-    case ResolutionRole: {
-        const QString path = b.filePath("preferred");
-
-        QSize *size = m_imageSizeCache.object(path);
-
-        if (size && size->isValid()) {
-            return QStringLiteral("%1x%2").arg(size->width()).arg(size->height());
-        }
-
-        asyncGetMediaMetadata(path, QPersistentModelIndex(index));
-
-        return QString();
-    }
-
     case PathRole: {
         if (qGray(qGuiApp->palette().window().color().rgb()) < 192) {
-            const QString darkPath = b.filePath(QByteArrayLiteral("preferredDark"));
+            const QString darkPath = b.package().filePath(QByteArrayLiteral("preferredDark"));
             if (!darkPath.isEmpty()) {
                 return QUrl::fromLocalFile(darkPath);
             }
         }
 
-        return QUrl::fromLocalFile(b.filePath("preferred"));
+        return QUrl::fromLocalFile(b.package().filePath("preferred"));
     }
 
     case PackageNameRole:
-        return b.path();
+        return b.package().path();
 
     case RemovableRole: {
-        const QString path = b.path();
+        const QString path = b.package().path();
 
         return path.startsWith(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/wallpapers/"))
             || m_removableWallpapers.contains(path);
     }
 
     case PendingDeletionRole:
-        return m_pendingDeletion.value(b.path(), false);
+        return m_pendingDeletion.value(b.package().path(), false);
+
+    case SelectorsRole:
+        return b.selectors();
     }
     Q_UNREACHABLE();
 }
@@ -112,8 +101,8 @@ bool PackageListModel::setData(const QModelIndex &index, const QVariant &value,
     }
 
     if (role == PendingDeletionRole) {
-        const KPackage::Package &b = m_packages.at(index.row());
-        m_pendingDeletion[b.path()] = value.toBool();
+        const WallpaperPackage &b = m_packages.at(index.row());
+        m_pendingDeletion[b.package().path()] = value.toBool();
 
         Q_EMIT dataChanged(index, index, {PendingDeletionRole});
         return true;
@@ -122,16 +111,16 @@ bool PackageListModel::setData(const QModelIndex &index, const QVariant &value,
     return false;
 }
 
-int PackageListModel::indexOf(const QString &_path) const
+static QString normalizeDirName(const QString &filePath)
 {
-    QString path = _path.endsWith(QDir::separator()) ? _path : _path + QDir::separator();
+    return filePath.endsWith(QDir::separator()) ? filePath : filePath + QDir::separator();
+}
 
-    if (path.startsWith(QLatin1String("file://"))) {
-        path.remove(0, 7);
-    }
-
-    const auto it = std::find_if(m_packages.cbegin(), m_packages.cend(), [&path](const KPackage::Package &p) {
-        return path == p.path();
+int PackageListModel::indexOf(const QUrl &url) const
+{
+    const QString path = normalizeDirName(url.toLocalFile());
+    const auto it = std::find_if(m_packages.cbegin(), m_packages.cend(), [&path](const WallpaperPackage &p) {
+        return path == p.package().path();
     });
 
     if (it == m_packages.cend()) {
@@ -154,14 +143,14 @@ void PackageListModel::load(const QStringList &customPaths)
     QThreadPool::globalInstance()->start(finder);
 }
 
-QStringList PackageListModel::addBackground(const QString &path)
+QStringList PackageListModel::addBackground(const QUrl &url)
 {
-    if (path.isEmpty() || indexOf(path) >= 0 || !QFileInfo(path).isDir()) {
+    if (url.isEmpty() || indexOf(url) >= 0) {
         return {};
     }
 
     KPackage::Package package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Wallpaper/Images"));
-    package.setPath(path);
+    package.setPath(url.toLocalFile());
 
     if (!package.isValid() || !package.metadata().isValid()) {
         return {};
@@ -200,29 +189,27 @@ QStringList PackageListModel::addBackground(const QString &path)
     return {package.path()};
 }
 
-QStringList PackageListModel::removeBackground(const QString &_path)
+QStringList PackageListModel::removeBackground(const QUrl &url)
 {
     QStringList results;
 
-    if (_path.isEmpty()) {
+    if (url.isEmpty()) {
         return results;
     }
 
-    const QString path = _path.endsWith(QDir::separator()) ? _path : _path + QDir::separator();
-
-    const int idx = indexOf(path);
-
+    const int idx = indexOf(url);
     if (idx < 0) {
         return results;
     }
 
     beginRemoveRows(QModelIndex(), idx, idx);
 
-    m_pendingDeletion.remove(m_packages.at(idx).path());
-    m_removableWallpapers.removeOne(m_packages.at(idx).path());
-    results.append(m_packages.takeAt(idx).path());
+    m_pendingDeletion.remove(m_packages.at(idx).package().path());
+    m_removableWallpapers.removeOne(m_packages.at(idx).package().path());
+    results.append(m_packages.takeAt(idx).package().path());
 
     // Uninstall local package
+    const QString path = url.toLocalFile();
     if (path.startsWith(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/wallpapers/"))) {
         QDir f(path);
 
@@ -236,7 +223,7 @@ QStringList PackageListModel::removeBackground(const QString &_path)
     return results;
 }
 
-void PackageListModel::slotHandlePackageFound(const QList<KPackage::Package> &packages)
+void PackageListModel::slotHandlePackageFound(const QList<WallpaperPackage> &packages)
 {
     beginResetModel();
 
